Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
Adb string `json:"adb"` // adb binary name ("adb" by default)
Devices []string `json:"devices"` // list of adb device IDs to use
// Ensure that a device battery level is at 20+% before fuzzing.
// Sometimes we observe that a device can't charge during heavy fuzzing
// and eventually powers down (which then requires manual intervention).
// This option is enabled by default. Turn it off if your devices
// don't have battery service, or it causes problems otherwise.
BatteryCheck bool `json:"battery_check"`
}
Click to show internal directories.
Click to hide internal directories.